JsonWebSignature class

JSON Web Signature (JWS) represents content secured with digital signatures or Message Authentication Codes (MACs) using JSON-based data structures.

Inheritance

Constructors

JsonWebSignature.fromCompactSerialization(String serialization)
Constructs a JsonWebSignature from its compact serialization
factory
JsonWebSignature.fromJson(Map<String, dynamic> json)
Constructs a JsonWebSignature from its flattened or general JSON representation
factory

Properties

commonHeader → JoseHeader
The JOSE header
no setterinherited
commonProtectedHeader → JoseHeader
The JOSE header parameters that are integrity protected
no setterinherited
data → List<int>
The binary data contained in this object
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
recipients → List<JoseRecipient>
The per-recipient content of this object
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedProtectedHeader → JsonObject?
Header parameters that are integrity protected and shared by all recipients
finalinherited
sharedUnprotectedHeader → JsonObject?
Header parameters that are not integrity protected and are shared by all recipients
finalinherited
unverifiedPayload → JosePayload
Returns the unverified payload (with the protected header parameters from the first signature)
no setter

Methods

getPayload(JsonWebKeyStore keyStore, {List<String>? allowedAlgorithms}) → Future<JosePayload>
Returns a future that resolves to the payload if the content of this object can be decrypted and verified. Otherwise the future fails with a JoseException
inherited
getPayloadFor(JsonWebKey? key, JoseHeader header, JoseRecipient recipient) → List<int>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCompactSerialization() → String
Serializes the JsonWebSignature or JsonWebEncryption to a string.
override
toJson() → Map<String, dynamic>
Serializes the JsonWebSignature or JsonWebEncryption to a JSON representation.
override
toString() → String
A string representation of this object.
inherited
verify(JsonWebKeyStore keyStore) → Future<bool>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited